/***************************************************************************

    Atari Lynx cartridges

***************************************************************************/

#include "emu.h"
#include "softlist.h"
#include "devices/cartslot.h"


#define LYNX_ROM_LOAD( set, name, offset, length, hash )	\
SOFTWARE_START( set ) \
	ROM_REGION( 0x100000, CARTRIDGE_REGION_ROM, ROMREGION_ERASEFF ) \
	ROM_LOAD(name, offset, length, hash) \
SOFTWARE_END


// FIXME: we should remove the 0x40 headers and use proper dumps...

LYNX_ROM_LOAD( apb,       "a.p.b. - all points bulletin (Euro, USA).lnx",                                            0x000000,  0x40040,	 CRC(68a0acab) SHA1(4abef1bc702319d4347d839ac8513193164a08a0) )
LYNX_ROM_LOAD( avsp,      "alien vs predator (usa) (prototype).lnx",                                                 0x000000,  0x40040,	 CRC(d6843e8e) SHA1(860a73b9484c78330d3502a70bb807d699d540dc) )
LYNX_ROM_LOAD( awesomeg,  "awesome golf (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(2b90e818) SHA1(c40ac4cc9a4aade0f7eab4283eed46d5882b35a8) )
LYNX_ROM_LOAD( bbheroes,  "baseball heroes (Euro, USA) [b].lnx",                                                     0x000000,  0x40040,	BAD_DUMP CRC(400989ea) SHA1(5e116d56e1642f107e15bb943416655917fbd607) )
LYNX_ROM_LOAD( basketbr,  "basketbrawl (Euro, USA).lnx",                                                             0x000000,  0x40040,	 CRC(a41b3d47) SHA1(cfe4708a881564b1ad75cdbe6da526c06d19a9c1) )
LYNX_ROM_LOAD( batmanrn,  "batman returns (Euro, USA).lnx",                                                          0x000000,  0x40040,	 CRC(68cd6dcb) SHA1(45df55597bae86b9184861d64d1a1d770f1e8c40) )
LYNX_ROM_LOAD( bwheels,   "battle wheels (Euro, USA).lnx",                                                           0x000000,  0x20040,	 CRC(fd5ae3db) SHA1(42f8a53fdba03358a65e82db81067e8e9aaba30b) )
LYNX_ROM_LOAD( bzone2k,   "battlezone 2000 (Euro, USA).lnx",                                                         0x000000,  0x40040,	 CRC(414bda9a) SHA1(7edfa01096a61f681dd4bf217ab1f0281c3b33b0) )
LYNX_ROM_LOAD( billted,   "bill & ted's excellent adventure (Euro, USA).lnx",                                        0x000000,  0x40040,	 CRC(c91aff8a) SHA1(f322d28a6311d84edc36b35083acc07a0ba4660a) )
LYNX_ROM_LOAD( blockout,  "block out (Euro, USA).lnx",                                                               0x000000,  0x20040,	 CRC(c96e5bc6) SHA1(2efb86ed51e676a6e59cce3b40e56f408fe84605) )
LYNX_ROM_LOAD( bluelghtd, "blue lightning (usa) (demo).lnx",                                                         0x000000,  0x20040,	 CRC(0bd1b69c) SHA1(d95653027c1956085a01541e3164ea637b52f100) )
LYNX_ROM_LOAD( bluelght,  "blue lightning (Euro, USA).lnx",                                                          0x000000,  0x20040,	 CRC(35af173c) SHA1(fd4dfa7b8822229c0e0c5b0f6cde608f8f94bb65) )
LYNX_ROM_LOAD( bubtroub,  "bubble trouble (Euro, USA).lnx",                                                          0x000000,  0x40040,	 CRC(96df6fa0) SHA1(b5c4824271e4a86052d65e0dfeb01b0ada1f3600) )
LYNX_ROM_LOAD( calgames,  "california games (Euro, USA).lnx",                                                        0x000000,  0x20040,	 CRC(2918ea2e) SHA1(9c89db856a1b85afdb0334d2bc5d9dffa1d3cca2) )
LYNX_ROM_LOAD( centiped,  "centipede (usa) (prototype).lnx",                                                         0x000000,  0x20040,	 CRC(70cc4ae8) SHA1(9954707eeba52904533cef59e5aae6e196434534) )
LYNX_ROM_LOAD( chekflag,  "checkered flag (Euro, USA).lnx",                                                          0x000000,  0x40040,	 CRC(6687f846) SHA1(848694715135979c022561ef9e4da58b8a67c4f3) )
LYNX_ROM_LOAD( chipchal,  "chip's challenge (Euro, USA).lnx",                                                        0x000000,  0x20040,	 CRC(f45f784a) SHA1(92af2d566c6bbf626a21dbfa41af16d73e0a774d) )
LYNX_ROM_LOAD( conquest,  "conquest of zow (1996).lnx",                                                              0x000000,  0x40040,	 CRC(9ccfdcd0) SHA1(41af0a1d8e4aa67b162394abf770e4a812f59a9f) )
LYNX_ROM_LOAD( crystalm,  "crystal mines ii (Euro, USA).lnx",                                                        0x000000,  0x40040,	 CRC(58ff6db3) SHA1(e8d6a939a202060a76e0417315c7693631116d57) )
LYNX_ROM_LOAD( daemongt,  "daemonsgate (usa) (prototype).lnx",                                                       0x000000,  0x40040,	 CRC(9e6b7645) SHA1(9e9bece7b410f909c661aaff44815b09d3d6b5aa) )
LYNX_ROM_LOAD( dstrike,   "desert strike - return to the gulf (Euro, USA).lnx",                                      0x000000,  0x40040,	 CRC(2eaae973) SHA1(1e529493866d6485074233458b40c4e7b0f032ef) )
LYNX_ROM_LOAD( dinolymp,  "dinolympics (Euro, USA).lnx",                                                             0x000000,  0x40040,	 CRC(0ed9eb06) SHA1(8af3a298ddb7ba235b54891c221ef53a2c89e9db) )
LYNX_ROM_LOAD( dirtylar,  "dirty larry - renegade cop (Euro, USA).lnx",                                              0x000000,  0x40040,	 CRC(c6017733) SHA1(c1d62142fc5094252637dbc6a2355e41d0425fc2) )
LYNX_ROM_LOAD( ddragon,   "double dragon (Euro, USA).lnx",                                                           0x000000,  0x40040,	 CRC(bcb2e75a) SHA1(1227eb28e6bad3c30b38d3dbfa9f929d836300c5) )
LYNX_ROM_LOAD( dracula,   "dracula the undead (Euro, USA).lnx",                                                      0x000000,  0x40040,	 CRC(0f4b4071) SHA1(824f245004a778613c85d40c9a2785a8cefe4181) )
LYNX_ROM_LOAD( dragnet,   "dragnet (1995).lnx",                                                                      0x000000,  0x40040,	 CRC(7cdc4f1b) SHA1(1333d7f43134d01cc6c62cfe66778b6fc7471dac) )
LYNX_ROM_LOAD( electroc,  "electrocop (Euro, USA).lnx",                                                              0x000000,  0x20040,	 CRC(765d742d) SHA1(c06e983638b4466322a15a367cdaeb56fc2486e6) )
LYNX_ROM_LOAD( eurosocc,  "european soccer challenge (Euro, USA).lnx",                                               0x000000,  0x20040,	 CRC(d714546d) SHA1(c3b6ed0e72aa6fcfab0ac72ce682fdd304314dff) )
LYNX_ROM_LOAD( eyebehol,  "eye of the beholder (usa) (prototype).lnx",                                               0x000000,  0x20040,	 CRC(a0010717) SHA1(6c37e1f220e73ff784b90c81846cebe4db0ab3bc) )
LYNX_ROM_LOAD( fatbobby,  "fat bobby (Euro, USA).lnx",                                                               0x000000,  0x40040,	 CRC(e2f4da44) SHA1(c7230ae604bec950522eb13aa549c3b1c603cebf) )
LYNX_ROM_LOAD( fidelity,  "fidelity ultimate chess challenge, the (Euro, USA).lnx",                                  0x000000,  0x20040,	 CRC(96643baa) SHA1(051f95a0c5b60e8c517b8df08f449110ed2bca68) )
LYNX_ROM_LOAD( gatezend,  "gates of zendocon, the (Euro, USA).lnx",                                                  0x000000,  0x20040,	 CRC(d852dba7) SHA1(d89985e2e692b335e3eb1e2a269ac2a2e4b3c8ad) )
LYNX_ROM_LOAD( gauntlet,  "gauntlet - the third encounter (Euro, USA).lnx",                                          0x000000,  0x20040,	 CRC(8e0908e5) SHA1(7cf7d08b52784e13d8278d249dcd8975d3714da4) )
LYNX_ROM_LOAD( gordo106,  "gordo 106 - the mutated lab monkey (Euro, USA).lnx",                                      0x000000,  0x40040,	 CRC(0671acea) SHA1(46fd69c68cb0929a2d21ecc5225390b7425ae3f4) )
LYNX_ROM_LOAD( harddriv,  "hard drivin' (Euro, USA).lnx",                                                            0x000000,  0x20040,	 CRC(9add0861) SHA1(afe1a2b3ed37596378b2d40f54e1635bf15c5600) )
LYNX_ROM_LOAD( hockey,    "hockey (Euro, USA).lnx",                                                                  0x000000,  0x40040,	 CRC(0904a4d9) SHA1(2f2d74cfba54360e7f5555d182a9e9e7f74287e8) )
LYNX_ROM_LOAD( hydra,     "hydra (Euro, USA).lnx",                                                                   0x000000,  0x40040,	 CRC(8980a322) SHA1(5ceb3ad748cd42e181067a191e2b0dccc0325057) )
LYNX_ROM_LOAD( ishido,    "ishido - the way of stones (Euro, USA).lnx",                                              0x000000,  0x40040,	 CRC(7c58aea4) SHA1(f7f2fb564c589fc8499f0aafd21ef13a38135947) )
LYNX_ROM_LOAD( jimmycon,  "jimmy connors' tennis (Euro, USA).lnx",                                                   0x000000,  0x80040,	 CRC(fdd6536d) SHA1(eb53241c8cac2456684c4b1fe86aa8c90e765d91) )
LYNX_ROM_LOAD( joust,     "joust (Euro, USA).lnx",                                                                   0x000000,  0x40040,	 CRC(9f7662c2) SHA1(9a72b390ce25ffe8400b7abdedd2ca61d3957cc3) )
LYNX_ROM_LOAD( klax,      "klax (Euro, USA).lnx",                                                                    0x000000,  0x40040,	 CRC(ec53a878) SHA1(66a04e14e07367a59fb979b25915008ac1602233) )
LYNX_ROM_LOAD( krazyace,  "krazy ace - miniature golf (Euro, USA).lnx",                                              0x000000,  0x40040,	 CRC(96c5d9b9) SHA1(8ddb2fc5898110f4069a47f91016d4ad3d014ac7) )
LYNX_ROM_LOAD( kungfood,  "kung food (Euro, USA).lnx",                                                               0x000000,  0x40040,	 CRC(3529d2d7) SHA1(ba5f63f558f818d4cf69173c9b00f1b0247a9282) )
LYNX_ROM_LOAD( lemmings,  "lemmings (Euro, USA).lnx",                                                                0x000000,  0x40040,	 CRC(a77b6b64) SHA1(e61c173116eacecf90d0296c03d8c216be57400c) )
LYNX_ROM_LOAD( lexis,     "lexis (Euro, USA).lnx",                                                                   0x000000,  0x40040,	 CRC(57bd4b4c) SHA1(86c0bf4dd546426b844b628cd8f847f3e5e2107b) )
LYNX_ROM_LOAD( loopz,     "loopz (usa) (prototype).lnx",                                                             0x000000,  0x40040,	 CRC(93281104) SHA1(fa7ce862c1ea15af4ffcf15e0cccc2a8a84b8e6d) )
LYNX_ROM_LOAD( lcasino,   "lynx casino (Euro, USA).lnx",                                                             0x000000,  0x40040,	 CRC(5539baf4) SHA1(a5fb943e2eeece25bc3aaf1e9f6ae5c030672193) )
LYNX_ROM_LOAD( lynx2tst,  "lynx ii production test program v0.02 (usa) (prototype).lnx",                             0x000000,  0x40040,	 CRC(93acf1dc) SHA1(d56925c596d47b17a4e778ba5d5475da447872d4) )
LYNX_ROM_LOAD( malibu,    "malibu bikini volleyball (Euro, USA).lnx",                                                0x000000,  0x40040,	 CRC(aba3e776) SHA1(f47f2aed04ba18152347aa2e0858b56c374c5f71) )
LYNX_ROM_LOAD( marlboro,  "marlboro go! (Euro) (prototype).lnx",                                                     0x000000,  0x40040,	 CRC(8d484e65) SHA1(3d0ee922c3572c9a861fc250082e659e6ebd4c8c) )
LYNX_ROM_LOAD( mspacman,  "ms. pac-man (Euro, USA).lnx",                                                             0x000000,  0x20040,	 CRC(fd071dd6) SHA1(26687ae97c5014e681f2ea44f401b314ad61c540) )
LYNX_ROM_LOAD( nflfoot,   "nfl football (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(c398359e) SHA1(22735fcd59eb028a4041027a369602b0bd968eb5) )
LYNX_ROM_LOAD( ninjag,    "ninja gaiden (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(5adf25f0) SHA1(e751c35cce6e2e126ce7ccbd32b148dd6e248809) )
LYNX_ROM_LOAD( ninjag3,   "ninja gaiden iii - the ancient ship of doom (Euro, USA).lnx",                             0x000000,  0x80040,	 CRC(cd2ffbcc) SHA1(70f4115a92e3fdc4c93339ac801976a7697397ba) )
LYNX_ROM_LOAD( pacland,   "pac-land (Euro, USA).lnx",                                                                0x000000,  0x20040,	 CRC(5b57126a) SHA1(ca4f651c9955b756a88d3e7714f033c592fa0f6a) )
LYNX_ROM_LOAD( paperboy,  "paperboy (Euro, USA).lnx",                                                                0x000000,  0x20040,	 CRC(d6a4c70b) SHA1(7b5150cc095c554b0578bdd9a20caec0a7921547) )
LYNX_ROM_LOAD( pinballj,  "pinball jam (Euro, USA).lnx",                                                             0x000000,  0x40040,	 CRC(8863c28d) SHA1(1f1695acbecf39cf6fd7afa71ce5f5e0ec80934d) )
LYNX_ROM_LOAD( pitfight,  "pit fighter - the ultimate competition (Euro, USA).lnx",                                  0x000000,  0x80040,	 CRC(cbaf54f3) SHA1(d87b768ec219ba468e050d4a6c71ef59854adb28) )
LYNX_ROM_LOAD( powfactr,  "power factor (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(5db41679) SHA1(858855f42fd24c692859f43df261dbc0e19f0819) )
LYNX_ROM_LOAD( qix,       "qix (Euro, USA).lnx",                                                                     0x000000,  0x20040,	 CRC(5651e1a8) SHA1(ab9545de5b867c930afed570668d03b1ee41a9dd) )
LYNX_ROM_LOAD( raiden,    "raiden (usa) (v3.0).lnx",                                                                 0x000000,  0x40040,	 CRC(2702ba4f) SHA1(752a58e02787afc145f5245aec3577ad4bff954e) )
LYNX_ROM_LOAD( rampage,   "rampage (Euro, USA).lnx",                                                                 0x000000,  0x40040,	 CRC(490033c9) SHA1(52a0bf6aa79be75c7f97e4f2998469fb8f1c1596) )
LYNX_ROM_LOAD( rampart,   "rampart (Euro, USA).lnx",                                                                 0x000000,  0x40040,	 CRC(adab7883) SHA1(d024992d0032bce698273e81d7276fba9a19f75f) )
LYNX_ROM_LOAD( roadriot,  "road riot 4wd (usa) (prototype).lnx",                                                     0x000000,  0x40040,	 CRC(3bebb6d1) SHA1(e6102b29727fd76177efd64c26f40dd6beee6888) )
LYNX_ROM_LOAD( roadblas,  "roadblasters (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(47f69051) SHA1(bc005446fb9e96848823e8baa722c6a7761783e1) )
LYNX_ROM_LOAD( robosqua,  "robo-squash (Euro, USA).lnx",                                                             0x000000,  0x20040,	 CRC(aeed3e7e) SHA1(a5a3204508207929b4b4e29d112b1653bb679b91) )
LYNX_ROM_LOAD( robotron,  "robotron 2084 (Euro, USA).lnx",                                                           0x000000,  0x20040,	 CRC(28c789c8) SHA1(ffc7e5a8d1b9226642e09b91d50cc30534e3c609) )
LYNX_ROM_LOAD( rygar,     "rygar - legendary warrior (Euro, USA).lnx",                                               0x000000,  0x40040,	 CRC(1dfca564) SHA1(24e14920178e3481f161783b73efca0a1594c8cf) )
LYNX_ROM_LOAD( stunrun,   "s.t.u.n. runner (Euro, USA).lnx",                                                         0x000000,  0x40040,	 CRC(4b3bf84f) SHA1(3ccd01902f07ab06f9c815ac75a4865a82e78599) )
LYNX_ROM_LOAD( scrapdog,  "scrapyard dog (Euro, USA).lnx",                                                           0x000000,  0x40040,	 CRC(ca0d1bda) SHA1(112e6433deca07dd49e2adf1a436cacfe94af7d6) )
LYNX_ROM_LOAD( beast,     "shadow of the beast (Euro, USA).lnx",                                                     0x000000,  0x40040,	 CRC(d43a8430) SHA1(f4bda927017465cfd417d5ad8a62fa095cc3a101) )
LYNX_ROM_LOAD( shanghai,  "shanghai (Euro, USA).lnx",                                                                0x000000,  0x20040,	 CRC(78ba01fd) SHA1(dbc5749a30d05c3fbb7e247d80405dd026bc8add) )
LYNX_ROM_LOAD( steeltal,  "steel talons (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(ab814832) SHA1(2d3536b3c5f3b8aa9dd5d952dbd43beac3043f6f) )
LYNX_ROM_LOAD( supaster,  "super asteroids, missile command (Euro, USA).lnx",                                        0x000000,  0x20040,	 CRC(7d8a25d1) SHA1(3b36e4e256ceabfd8ef8f86731d01bc191f7d5a7) )
LYNX_ROM_LOAD( superoff,  "super off-road (Euro, USA).lnx",                                                          0x000000,  0x40040,	 CRC(c51b7a2f) SHA1(825540819ec2dfee70b6d189f13c6c07c39d387d) )
LYNX_ROM_LOAD( supskwek,  "super skweek (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(11b712f6) SHA1(a6185962f6106bad3b20abe5bd724c6ea8c7ba34) )
LYNX_ROM_LOAD( switchb2,  "switchblade ii (Euro, USA).lnx",                                                          0x000000,  0x40040,	 CRC(63144491) SHA1(01fb0609e292d84de23adee31be44605e9d0503c) )
LYNX_ROM_LOAD( tres,      "t-res (title unknown) (199x) [b1].lnx",                                                   0x000000,  0x20040,	 CRC(dd0fe131) SHA1(a8d97587a5749d19158d1749ee998c520b7c71fe) )
LYNX_ROM_LOAD( tetris1,   "tetris (1996) [b1].lnx",                                                                  0x000000,  0x40040,	 CRC(f8218bb3) SHA1(3b8c1b399307cdb1103cbe6ae5d53f25e07a12c9) )
LYNX_ROM_LOAD( tetris2,   "tetris (1996) [b2].lnx",                                                                  0x000000,  0x4001f,	 CRC(8c803b33) SHA1(df431f2748f54bdd6b77380712b04fc0dea609c0) )
LYNX_ROM_LOAD( tetris3,   "tetris (1996) [b3].lnx",                                                                  0x000000,  0x40040,	 CRC(22bfcedf) SHA1(a3c8fbb6ecbe989f589313e3a708f1dd674a8f46) )
LYNX_ROM_LOAD( toddsadv,  "todd's adventures in slime world (Euro, USA).lnx",                                        0x000000,  0x20040,	 CRC(39bf3c25) SHA1(a1914219cc572c8e41becd61839abac72e811260) )
LYNX_ROM_LOAD( toki,      "toki (Euro, USA).lnx",                                                                    0x000000,  0x40040,	 CRC(52b94a6c) SHA1(9a01844c003e7755bd3b219f028fd2bd9eee1640) )
LYNX_ROM_LOAD( tcyberbl,  "tournament cyberball 2072 (Euro, USA).lnx",                                               0x000000,  0x40040,	 CRC(70d0c9bf) SHA1(e2d5f95b046ec0950cf872413202ec504dbf5338) )
LYNX_ROM_LOAD( turbosub,  "turbo sub (Euro, USA).lnx",                                                               0x000000,  0x20040,	 CRC(5247b5f3) SHA1(b56ea80870a19ac3436a66c80447a2aa0ff49d83) )
LYNX_ROM_LOAD( viking,    "viking child (Euro, USA).lnx",                                                            0x000000,  0x40040,	 CRC(45969eb0) SHA1(2a0a1e303da1d8fc2ea1c59a16398946787614a6) )
LYNX_ROM_LOAD( warbirds,  "warbirds (Euro, USA).lnx",                                                                0x000000,  0x20040,	 CRC(a6ae2301) SHA1(340e76e14d0d1b961d2c2d2b1b7146381dda3a48) )
LYNX_ROM_LOAD( wcsoccer,  "world class soccer (Euro, USA).lnx",                                                      0x000000,  0x40040,	 CRC(9d929f2c) SHA1(cc2e2a4cefbaa3ec6961a4e23b2f37262f9816c8) )
LYNX_ROM_LOAD( xenophob,  "xenophobe (Euro, USA).lnx",                                                               0x000000,  0x20040,	 CRC(922a9dd0) SHA1(1f8a8e144d8ea19cfb2ec2f198060ba933b94849) )
LYNX_ROM_LOAD( xybots,    "xybots (Euro, USA).lnx",                                                                  0x000000,  0x40040,	 CRC(cac9a246) SHA1(c3c117db6060d2b99d914e96284d4c2da723d033) )
LYNX_ROM_LOAD( zarlor,    "zarlor mercenary (Euro, USA).lnx",                                                        0x000000,  0x20040,	 CRC(35bc4ff9) SHA1(24397a46e45ae34d7b06b222c56f950976ab44b6) )


/*
Undumped games:
* Hyperdrome (Telegames 1999)

Undumped Self-Published Titles:
* Alpine Games (R. & J. Graf)
* CGE 5th (Songbird Productions, CF30B2)
* Championship Rally (Songbird Productions, CF2006)
* Crystal Mines II - Buried Treasure (Songbird Productions, CF2008)
* Cyber Virus (Songbird Productions, CF2007)
* Cyber Virus - CinciClassic Edition (Songbird Productions, CF20B1)
* Lynx Othello (H. Dodgson)
* MegaPak 1 (Songbird Productions, CF2010)  - too new (2008)
* PokerMania (MW Software)
* Ponx (Songbird Productions, CF2002)
* Remnant - Planar Wars 3D (Songbird Productions, CF2005)
* SFX - The Ultimate Audio Tool (Songbird Productions, CF2001)
* S.I.M.I.S. (B. Schick & M. Domin)
* SokoMania (MW Software)
* T-tris (B. Schick)

Known undumped prototypes:
* Cyber Virus (Beyond Games)
* Dungeon Slayers (Atari)
* GeoDuel (Atari)
* Lode Runner
* Mechtiles (Atari)
* Pounce (Atari)
* Relief Pitcher (Atari)
* Ultra Vortex (Atari)
* Vindicators (Atari)

*/

SOFTWARE_LIST_START( lynx_cart )
	SOFTWARE( apb,       0,        1991, "Atari", "A.P.B. (Euro, USA)", 0, 0 )
	SOFTWARE( avsp,      0,        199?, "Atari", "Alien vs Predator (USA, Prototype)", 0, 0 )
	SOFTWARE( awesomeg,  0,        1991, "Atari", "Awesome Golf (Euro, USA)", 0, 0 )
	SOFTWARE( bbheroes,  0,        1992, "Atari", "Baseball Heroes (Euro, USA)", 0, 0 )	// Bad dump
	SOFTWARE( basketbr,  0,        1992, "Atari", "Basketbrawl (Euro, USA)", 0, 0 )
	SOFTWARE( batmanrn,  0,        1992, "Atari", "Batman Returns (Euro, USA)", 0, 0 )
	SOFTWARE( bwheels,   0,        1993, "Beyond Games", "Battle Wheels (Euro, USA)", 0, 0 )
	SOFTWARE( bzone2k,   0,        1995, "Atari", "Battlezone 2000 (Euro, USA)", 0, 0 )
	SOFTWARE( billted,   0,        1991, "Atari", "Bill & Ted's Excellent Adventure (Euro, USA)", 0, 0 )
	SOFTWARE( blockout,  0,        1991, "Atari", "Block Out (Euro, USA)", 0, 0 )
	SOFTWARE( bluelghtd, bluelght, 1989, "Atari", "Blue Lightning (USA, Demo)", 0, 0 )
	SOFTWARE( bluelght,  0,        1989, "Atari", "Blue Lightning (Euro, USA)", 0, 0 )
	SOFTWARE( bubtroub,  0,        1994, "Telegames", "Bubble Trouble (Euro, USA)", 0, 0 )
	SOFTWARE( calgames,  0,        1989, "Atari", "California Games (Euro, USA)", 0, 0 )
	SOFTWARE( centiped,  0,        199?, "Shadowsoft", "Centipede (USA, Prototype)", 0, 0 )
	SOFTWARE( chekflag,  0,        1991, "Atari", "Checkered Flag (Euro, USA)", 0, 0 )
	SOFTWARE( chipchal,  0,        1989, "Atari", "Chip's Challenge (Euro, USA)", 0, 0 )
	SOFTWARE( crystalm,  0,        1992, "Atari", "Crystal Mines II (Euro, USA)", 0, 0 )
	SOFTWARE( daemongt,  0,        199?, "Atari", "Daemonsgate (USA, Prototype)", 0, 0 )
	SOFTWARE( dstrike,   0,        1993, "Telegames", "Desert Strike - Return to the Gulf (Euro, USA)", 0, 0 )
	SOFTWARE( dinolymp,  0,        1992, "Atari", "Dinolympics (Euro, USA)", 0, 0 )
	SOFTWARE( dirtylar,  0,        1992, "Atari", "Dirty Larry - Renegade Cop (Euro, USA)", 0, 0 )
	SOFTWARE( ddragon,   0,        1993, "Telegames", "Double Dragon (Euro, USA)", 0, 0 )
	SOFTWARE( dracula,   0,        1992, "Atari", "Dracula the Undead (Euro, USA)", 0, 0 )
	SOFTWARE( electroc,  0,        1989, "Atari", "Electrocop (Euro, USA)", 0, 0 )
	SOFTWARE( eurosocc,  0,        1993, "Telegames", "European Soccer Challenge (Euro, USA)", 0, 0 )
	SOFTWARE( eyebehol,  0,        199?, "NuFX", "Eye of the Beholder (USA, Prototype)", 0, 0 )
	SOFTWARE( fatbobby,  0,        199?, "Telegames", "Fat Bobby (Euro, USA)", 0, 0 )
	SOFTWARE( fidelity,  0,        1991, "Telegames", "The Fidelity Ultimate Chess Challenge (Euro, USA)", 0, 0 )
	SOFTWARE( gatezend,  0,        1989, "Atari", "Gates of Zendocon (Euro, USA)", 0, 0 )
	SOFTWARE( gauntlet,  0,        1990, "Atari", "Gauntlet - The Third Encounter (Euro, USA)", 0, 0 )
	SOFTWARE( gordo106,  0,        1993, "Atari", "Gordo 106 - The Mutated Lab Monkey (Euro, USA)", 0, 0 )
	SOFTWARE( harddriv,  0,        1991, "Atari", "Hard Drivin' (Euro, USA)", 0, 0 )
	SOFTWARE( hockey,    0,        1992, "Atari", "Hockey (Euro, USA)", 0, 0 )
	SOFTWARE( hydra,     0,        1992, "Atari", "Hydra (Euro, USA)", 0, 0 )
	SOFTWARE( ishido,    0,        1991, "Atari", "Ishido - The Way of Stones (Euro, USA)", 0, 0 )
	SOFTWARE( jimmycon,  0,        1993, "Atari", "Jimmy Connors' Tennis (Euro, USA)", 0, 0 )
	SOFTWARE( joust,     0,        1992, "Williams Entertainment", "Joust (Euro, USA)", 0, 0 )
	SOFTWARE( klax,      0,        1990, "Atari", "Klax (Euro, USA)", 0, 0 )
	SOFTWARE( krazyace,  0,        1993, "Telegames", "Krazy Ace - Miniature Golf (Euro, USA)", 0, 0 )
	SOFTWARE( kungfood,  0,        1992, "Atari", "Kung Food (Euro, USA)", 0, 0 )
	SOFTWARE( lemmings,  0,        1993, "Atari", "Lemmings (Euro, USA)", 0, 0 )
	SOFTWARE( lexis,     0,        1999, "Songbird Productions", "Lexis (Euro, USA)", 0, 0 )
	SOFTWARE( loopz,     0,        2004, "Songbird Productions", "Loopz (USA, Prototype)", 0, 0 )
	SOFTWARE( lcasino,   0,        1992, "Atari", "Lynx Casino (Euro, USA)", 0, 0 )
	SOFTWARE( malibu,    0,        1993, "Atari", "Malibu Bikini Volleyball (Euro, USA)", 0, 0 )
	SOFTWARE( marlboro,  0,        1993, "Digital Image", "Marlboro Go! (Euro, Prototype)", 0, 0 )
	SOFTWARE( mspacman,  0,        1990, "Atari", "Ms. Pac-Man (Euro, USA)", 0, 0 )
	SOFTWARE( nflfoot,   0,        1992, "Atari", "NFL Football (Euro, USA)", 0, 0 )
	SOFTWARE( ninjag,    0,        1991, "Atari", "Ninja Gaiden (Euro, USA)", 0, 0 )
	SOFTWARE( ninjag3,   0,        1993, "Atari", "Ninja Gaiden III - The Ancient Ship of Doom (Euro, USA)", 0, 0 )
	SOFTWARE( pacland,   0,        1991, "Atari", "Pac-Land (Euro, USA)", 0, 0 )
	SOFTWARE( paperboy,  0,        1990, "Atari", "Paperboy (Euro, USA)", 0, 0 )
	SOFTWARE( pinballj,  0,        1992, "Atari", "Pinball Jam (Euro, USA)", 0, 0 )
	SOFTWARE( pitfight,  0,        1992, "Atari", "Pit Fighter - The Ultimate Competition (Euro, USA)", 0, 0 )
	SOFTWARE( powfactr,  0,        1992, "Atari", "Power Factor (Euro, USA)", 0, 0 )
	SOFTWARE( qix,       0,        1991, "Telegames", "Qix (Euro, USA)", 0, 0 )
	SOFTWARE( raiden,    0,        1997, "Telegames", "Raiden (USA, v3.0)", 0, 0 )
	SOFTWARE( rampage,   0,        1990, "Atari", "Rampage (Euro, USA)", 0, 0 )
	SOFTWARE( rampart,   0,        1992, "Atari", "Rampart (Euro, USA)", 0, 0 )
	SOFTWARE( roadriot,  0,        199?, "Atari", "Road Riot 4WD (USA, Prototype)", 0, 0 )
	SOFTWARE( roadblas,  0,        1990, "Atari", "RoadBlasters (Euro, USA)", 0, 0 )
	SOFTWARE( robosqua,  0,        1990, "Atari", "Robo-Squash (Euro, USA)", 0, 0 )
	SOFTWARE( robotron,  0,        1991, "Williams Entertainment", "Robotron 2084 (Euro, USA)", 0, 0 )
	SOFTWARE( rygar,     0,        1990, "Atari", "Rygar - Legendary Warrior (Euro, USA)", 0, 0 )
	SOFTWARE( stunrun,   0,        1991, "Atari", "S.T.U.N. Runner (Euro, USA)", 0, 0 )
	SOFTWARE( scrapdog,  0,        1991, "Atari", "Scrapyard Dog (Euro, USA)", 0, 0 )
	SOFTWARE( beast,     0,        1992, "Atari", "Shadow of the Beast (Euro, USA)", 0, 0 )
	SOFTWARE( shanghai,  0,        1990, "Atari", "Shanghai (Euro, USA)", 0, 0 )
	SOFTWARE( steeltal,  0,        1992, "Atari", "Steel Talons (Euro, USA)", 0, 0 )
	SOFTWARE( supaster,  0,        1995, "Atari", "Super Asteroids - Missile Command (Euro, USA)", 0, 0 )
	SOFTWARE( superoff,  0,        1993, "Telegames", "Super Off-Road (Euro, USA)", 0, 0 )
	SOFTWARE( supskwek,  0,        1991, "Atari", "Super Skweek (Euro, USA)", 0, 0 )
	SOFTWARE( switchb2,  0,        1992, "Atari", "Switchblade II (Euro, USA)", 0, 0 )
	SOFTWARE( toddsadv,  0,        1990, "Atari", "Todd's Adventures in Slime World (Euro, USA)", 0, 0 )
	SOFTWARE( toki,      0,        1992, "Atari", "Toki (Euro, USA)", 0, 0 )
	SOFTWARE( tcyberbl,  0,        1991, "Atari", "Tournament Cyberball 2072 (Euro, USA)", 0, 0 )
	SOFTWARE( turbosub,  0,        1991, "Atari", "Turbo Sub (Euro, USA)", 0, 0 )
	SOFTWARE( viking,    0,        1991, "Atari", "Viking Child (Euro, USA)", 0, 0 )
	SOFTWARE( warbirds,  0,        1991, "Atari", "Warbirds (Euro, USA)", 0, 0 )
	SOFTWARE( wcsoccer,  0,        1992, "Atari", "World Class Soccer (Euro, USA)", 0, 0 )
	SOFTWARE( xenophob,  0,        1990, "Atari", "Xenophobe (Euro, USA)", 0, 0 )
	SOFTWARE( xybots,    0,        1991, "Atari", "Xybots (Euro, USA)", 0, 0 )
	SOFTWARE( zarlor,    0,        1990, "Atari", "Zarlor Mercenary (Euro, USA)", 0, 0 )

	/* Self Published carts */
	// NONE ATM

	/* Where do these come from?!? */
	SOFTWARE( dragnet,   0,        1995, "<unknown>", "Dragnet", 0, 0 )
	SOFTWARE( conquest,  0,        1996, "<unknown>", "Conquest of Zow", 0, 0 )

	/* These are all the same game (see the string "(c) 1993/94 B.Schick"). Probably it's a dump of the self published cart T-tris */
	SOFTWARE( tres,      0,        19??, "<unknown>", "T-RES (title unknown) (199x) [b1]", 0, 0 )
	SOFTWARE( tetris1,   0,        19??, "<unknown>", "Tetris (1996) [b1]", 0, 0 )
	SOFTWARE( tetris2,   0,        19??, "<unknown>", "Tetris (1996) [b2]", 0, 0 )
	SOFTWARE( tetris3,   0,        19??, "<unknown>", "Tetris (1996) [b3]", 0, 0 )

	SOFTWARE( lynx2tst,  0,        19??, "<unknown>", "Lynx II Production Test Program V0.02 (USA, Prototype)", 0, 0 )
SOFTWARE_LIST_END


SOFTWARE_LIST( lynx_cart, "Atari Lynx cartridges" )
